@@ -1,6 +1,6 @@
-from .file_utils import (open_file)
-from .core_utils import (isNone, compare_lowers, get_self, is_self, refresh, _selected_rows, select_all_by_type, move_window, control_window, should_close, close_selected, activate_window)
 from .update_utils import (update_table, update_monitor_dropdown)
+from .file_utils import (open_file)
+from .core_utils import (get_self, is_self, refresh, _selected_rows, select_all_by_type, move_window, control_window, should_close, close_selected, activate_window)
 from .build_ui import (_build_ui)
 from .wmctrl_utils import (get_monitors, get_windows, _compute_self_ids)
 from .command_utils import (run_command)
