@@ -1,4 +1,3 @@
 from consoles import *
 from abstract_gui import *
-startConsole(launcherWindowTab)
-
+startWindowManagerConsole()
